@@ -42,6 +42,11 @@ extern const char *COMMUNICATION_TAB;
  */
 extern const char *MAIN_CONTROL_TAB;
 
+/**
+ * @brief CONNECTION_TAB Where all device connection settings (serial, usb, ethernet) are defined and controlled.
+ */
+extern const char *CONNECTION_TAB;
+
 /**
  * @brief MOTION_TAB Where all the motion control properties of the device are located.
  */
@@ -119,6 +124,9 @@ class INDI::DefaultDevice : public INDI::BaseDevice
     /** \brief Add Configuration control to the driver */
     void addConfigurationControl();
 
+    /** \brief Add Polling period control to the driver */
+    void addPollPeriodControl();
+
     /** \brief Set all properties to IDLE state */
     void resetProperties();
 
@@ -183,7 +191,7 @@ class INDI::DefaultDevice : public INDI::BaseDevice
      * \param ms timer duration in milliseconds.
      * \return id of the timer to be used with RemoveTimer
     */
-    int SetTimer(int ms);
+    int SetTimer(uint32_t ms);
 
     /**
      * \brief Remove timer added with SetTimer
@@ -433,32 +441,37 @@ class INDI::DefaultDevice : public INDI::BaseDevice
     /** @return Return actively selected connection plugin */
     Connection::Interface *getActiveConnection() { return activeConnection; }
 
+    void setDefaultPollingPeriod(uint32_t period);
+    uint32_t getPollingPeriod() { return static_cast<uint32_t>(PollPeriodN[0].value); }
+
     /** \return Default name of the device. */
     virtual const char *getDefaultName() = 0;
 
     /// Period in milliseconds to call TimerHit(). Default 1000 ms
-    uint32_t updatePeriodMS = 1000;
+    uint32_t POLLMS = 1000;
 
   private:
-    bool isInit;
-    bool pDebug;
-    bool pSimulation;
+    bool isInit { false };
+    bool pDebug { false };
+    bool pSimulation { false };
 
-    uint16_t majorVersion;
-    uint16_t minorVersion;
-    uint16_t interfaceDescriptor;
+    uint16_t majorVersion { 1 };
+    uint16_t minorVersion { 0 };
+    uint16_t interfaceDescriptor { 0 };
 
     ISwitch DebugS[2];
     ISwitch SimulationS[2];
     ISwitch ConfigProcessS[3];
     ISwitch ConnectionS[2];
+    INumber PollPeriodN[1];
 
     ISwitchVectorProperty DebugSP;
     ISwitchVectorProperty SimulationSP;
     ISwitchVectorProperty ConfigProcessSP;
     ISwitchVectorProperty ConnectionSP;
+    INumberVectorProperty PollPeriodNP;
 
-    IText DriverInfoT[4];
+    IText DriverInfoT[4] {};
     ITextVectorProperty DriverInfoTP;
 
     // Connection modes
@@ -471,6 +484,7 @@ class INDI::DefaultDevice : public INDI::BaseDevice
     // Connection Plugins
     friend class Connection::Serial;
     friend class Connection::TCP;
+    friend class FilterInterface;
 
     bool defineDynamicProperties = true;
     bool deleteDynamicProperties = true;
