@@ -33,26 +33,41 @@
 
 
     </ul>
-    
+
     \author Jason Harris
     \author Elwood C. Downey
     \author Jasem Mutlaq
 */
 
-#ifndef INDICOM_H
-#define INDICOM_H
+#pragma once
 
-#define J2000 2451545.0
+#define J2000       2451545.0
 #define ERRMSG_SIZE 1024
-#define INDI_DEBUG
 
-extern const char * Direction[];
-extern const char * SolarSystem[];
+#define STELLAR_DAY        86164.098903691
+#define TRACKRATE_SIDEREAL ((360.0 * 3600.0) / STELLAR_DAY)
+#define SOLAR_DAY          86400
+#define TRACKRATE_SOLAR    ((360.0 * 3600.0) / SOLAR_DAY)
+#define TRACKRATE_LUNAR    14.511415
+
+extern const char *Direction[];
+extern const char *SolarSystem[];
 
 struct ln_date;
 
 /* TTY Error Codes */
-enum TTY_ERROR { TTY_OK=0, TTY_READ_ERROR=-1, TTY_WRITE_ERROR=-2, TTY_SELECT_ERROR=-3, TTY_TIME_OUT=-4, TTY_PORT_FAILURE=-5, TTY_PARAM_ERROR=-6, TTY_ERRNO = -7};
+enum TTY_ERROR
+{
+    TTY_OK           = 0,
+    TTY_READ_ERROR   = -1,
+    TTY_WRITE_ERROR  = -2,
+    TTY_SELECT_ERROR = -3,
+    TTY_TIME_OUT     = -4,
+    TTY_PORT_FAILURE = -5,
+    TTY_PARAM_ERROR  = -6,
+    TTY_ERRNO        = -7,
+    TTY_OVERFLOW     = -8
+};
 
 #ifdef __cplusplus
 extern "C" {
@@ -85,6 +100,17 @@ int tty_read(int fd, char *buf, int nbytes, int timeout, int *nbytes_read);
 
 int tty_read_section(int fd, char *buf, char stop_char, int timeout, int *nbytes_read);
 
+/** \brief read buffer from terminal with a delimiter
+    \param fd file descriptor
+    \param buf pointer to store data. Must be initilized and big enough to hold data.
+    \param stop_char if the function encounters \e stop_char then it stops reading and returns the buffer.
+    \param nsize size of buf. If stop character is not encountered before nsize, the function aborts.
+    \param timeout number of seconds to wait for terminal before a timeout error is issued.
+    \param nbytes_read the number of bytes read.
+    \return On success, it returns TTY_OK, otherwise, a TTY_ERROR code.
+*/
+
+int tty_nread_section(int fd, char *buf, int nsize, char stop_char, int timeout, int *nbytes_read);
 
 /** \brief Writes a buffer to fd.
     \param fd file descriptor
@@ -93,7 +119,7 @@ int tty_read_section(int fd, char *buf, char stop_char, int timeout, int *nbytes
     \param nbytes_written the number of bytes written
     \return On success, it returns TTY_OK, otherwise, a TTY_ERROR code.
 */
-int tty_write(int fd, const char * buffer, int nbytes, int *nbytes_written);
+int tty_write(int fd, const char *buffer, int nbytes, int *nbytes_written);
 
 /** \brief Writes a null terminated string to fd.
     \param fd file descriptor
@@ -101,8 +127,7 @@ int tty_write(int fd, const char * buffer, int nbytes, int *nbytes_written);
     \param nbytes_written the number of bytes written
     \return On success, it returns TTY_OK, otherwise, a TTY_ERROR code.
 */
-int tty_write_string(int fd, const char * buffer, int *nbytes_written);
-
+int tty_write_string(int fd, const char *buffer, int *nbytes_written);
 
 /** \brief Establishes a tty connection to a terminal device.
     \param device the device node. e.g. /dev/ttyS0
@@ -135,6 +160,9 @@ void tty_error_msg(int err_code, char *err_msg, int err_msg_len);
  * @param debug 1 to enable, 0 to disable
  */
 void tty_set_debug(int debug);
+void tty_set_gemini_udp_format(int enabled);
+void tty_set_skywatcher_udp_format(int enabled);
+void tty_clr_trailing_read_lf(int enabled);
 
 int tty_timeout(int fd, int timeout);
 /*@}*/
@@ -145,9 +173,9 @@ int tty_timeout(int fd, int timeout);
 /*@{*/
 
 /** \brief Converts a sexagesimal number to a string.
- 
+
    sprint the variable a in sexagesimal format into out[].
-	
+
   \param out a pointer to store the sexagesimal number.
   \param a the sexagesimal number to convert.
   \param w the number of spaces in the whole part.
@@ -157,29 +185,32 @@ int tty_timeout(int fd, int timeout);
  	  \li 3600:	\<w\>:mm:ss
  	  \li 600:	\<w\>:mm.m
  	  \li 60:	\<w\>:mm
-  
+
   \return number of characters written to out, not counting final null terminator.
  */
-int fs_sexa (char *out, double a, int w, int fracbase);
+int fs_sexa(char *out, double a, int w, int fracbase);
 
 /** \brief convert sexagesimal string str AxBxC to double.
 
     x can be anything non-numeric. Any missing A, B or C will be assumed 0. Optional - and + can be anywhere.
-    
+
     \param str0 string containing sexagesimal number.
     \param dp pointer to a double to store the sexagesimal number.
     \return return 0 if ok, -1 if can't find a thing.
  */
-int f_scansexa (const char *str0, double *dp);
+int f_scansexa(const char *str0, double *dp);
 
 /** \brief Extract ISO 8601 time and store it in a tm struct.
     \param timestr a string containing date and time in ISO 8601 format.
     \param iso_date a pointer to a \e ln_date structure to store the extracted time and date (libnova).
     \return 0 on success, -1 on failure.
 */
+#ifndef _WIN32
 int extractISOTime(const char *timestr, struct ln_date *iso_date);
+#endif
 
 void getSexComponents(double value, int *d, int *m, int *s);
+void getSexComponentsIID(double value, int *d, int *m, double *s);
 
 /** \brief Fill buffer with properly formatted INumber string.
     \param buf to store the formatted string.
@@ -189,12 +220,12 @@ void getSexComponents(double value, int *d, int *m, int *s);
 
     \note buf must be of length MAXINDIFORMAT at minimum
 */
-int numberFormat (char *buf, const char *format, double value);
+int numberFormat(char *buf, const char *format, double value);
 
 /** \brief Create an ISO 8601 formatted time stamp. The format is YYYY-MM-DDTHH:MM:SS
     \return The formatted time stamp.
 */
-const char *timestamp (void);
+const char *timestamp();
 
 /**
  * @brief rangeHA Limits the hour angle value to be between -12 ---> 12
@@ -225,11 +256,11 @@ double range360(double r);
 double rangeDec(double r);
 
 /**
- * @brief get_local_sideral_time Returns local sideral time given longitude and system clock.
+ * @brief get_local_sidereal_time Returns local sideral time given longitude and system clock.
  * @param longitude Longitude in INDI format (0 to 360) increasing eastward.
- * @return Local Sideral Time.
+ * @return Local Sidereal Time.
  */
-double get_local_sideral_time(double longitude);
+double get_local_sidereal_time(double longitude);
 
 /**
  * @brief get_local_hour_angle Returns local hour angle of an object
@@ -244,6 +275,3 @@ double get_local_hour_angle(double local_sideral_time, double ra);
 #ifdef __cplusplus
 }
 #endif
-
-
-#endif
